HueDirection

Enum HueDirection 

#[non_exhaustive]
#[repr(u8)]
pub enum HueDirection { Shorter = 0, Longer = 1, Increasing = 2, Decreasing = 3, }
The hue direction for interpolation.

This type corresponds to hue-interpolation-method in the CSS Color 4 spec.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Shorter = 0

Hue angles take the shorter of the two arcs between starting and ending values.



Longer = 1

Hue angles take the longer of the two arcs between starting and ending values.



Increasing = 2

Hue angles increase as they are interpolated.



Decreasing = 3

Hue angles decrease as they are interpolated.