Struct Aces2065_1
pub struct Aces2065_1;Expand description
🌌 The ACES2065-1 color space.
This is a linear color space with a very wide gamut. It is is often used for archival and interchange.
Its components are [r, g, b] (red, green, and blue channels respectively), with [0, 0, 0]
pure black and [1, 1, 1] white. The natural bounds of the components are
[-65504.0, 65504.0].
This color space is characterized by the Academy Color Encoding System and is specified in SMPTE ST 2065-1:2021.
ACES2065-1 has a reference white near D60; see the XYZ-D65 color space documentation for some background information on the meaning of “reference white.”
See also AcesCg.