AcesCg

Struct AcesCg 

pub struct AcesCg;
🌌 The ACEScg color space.

The ACEScg color space is a linear color space. The wide gamut makes this color space useful as a working space for computer graphics.

Its components are [r, g, b] (red, green, and blue channels respectively), with [0, 0, 0] pure black and [1, 1, 1] white. The natural bounds of the components are [-65504.0, 65504.0], though it is unusual to clip in this color space.

This color space is defined by the Academy Color Encoding System specification.

ACEScg has a reference white near D60; see the XYZ-D65 color space documentation for some background information on the meaning of “reference white.”

See also Aces2065_1.