Chromaticity

Struct Chromaticity 

pub struct Chromaticity {
    pub x: f32,
    pub y: f32,
}
CIE xy chromaticity, specifying a color in the XYZ color space, but not its luminosity.

An absolute color can be specified by adding a luminosity coordinate Y as in xyY. An XYZ color can be calculated from xyY as follows.

X = Y/y * x
Y = Y
Z = Y/y * (1 - x - y)

Fields

x: f32

The x-coordinate of the CIE xy chromaticity.

y: f32

The y-coordinate of the CIE xy chromaticity.

Implementations



impl Chromaticity

pub const D65: Chromaticity

The CIE D65 white point under the standard 2° observer.

This is a common white point for color spaces targeting monitors.

The white point’s chromaticities are truncated to four digits here, as specified by the CSS Color 4 specification, and following most color spaces using this white point.

pub const D50: Chromaticity

The CIE D50 white point under the standard 2° observer.

The white point’s chromaticities are truncated to four digits here, as specified by the CSS Color 4 specification, and following most color spaces using this white point.

pub const ACES: Chromaticity

The ACES white point.

This is the reference white of ACEScg and ACES2065-1. The white point is near the D60 white point under the standard 2° observer.