Hwb

Struct Hwb 

pub struct Hwb;
🌌 The HWB color space

The HWB color space is a convenient way to represent colors. It corresponds closely to popular color pickers, both a triangle with white, black, and fully saturated color at the corner, and also a rectangle with a hue spectrum at the top and black at the bottom, with whiteness as a separate slider. It was proposed in HWB–A More Intuitive Hue-Based Color Model.

Its components are [H, W, B] with

  • H - the hue angle in degrees, with red at 0, green at 120, and blue at 240.
  • W - an amount of whiteness to mix in, with 100 being white.
  • B - an amount of blackness to mix in, with 100 being black.

The hue angle is the same as in Hsl, and thus has the same flaw of poor hue uniformity.

This corresponds to the color space in CSS Color Module Level 4  8.