Struct Lch
pub struct Lch;Expand description
🌌 The cylindrical version of the Lab color space.
Its components are [L, C, h] with
L- the lightness as inLab;C- the chromatic intensity, the natural lower bound of 0 being achromatic, usually not exceeding 160; andh- the hue angle in degrees.
See Oklch for a similar color space but with better hue linearity.