Missing

Struct Missing 

pub struct Missing(u8);
Missing color components, extracted from Flags.

Some bitwise operations are implemented on this type, making certain manipulations more ergonomic.

Tuple Fields

0: u8

Implementations



impl Missing

pub const EMPTY: Missing

The set containing no missing components.

pub const fn single(ix: usize) -> Missing

The set containing a single component index.

pub const fn contains(self, ix: usize) -> bool

Returns true if the set contains the component index.

pub fn insert(&mut self, ix: usize)

Add a missing component index to the set.

pub const fn is_empty(self) -> bool

Returns true if the set contains no indices.