Struct Oklab
pub struct Oklab;Expand description
🌌 The Oklab color space, intended to be a perceptually uniform color space.
Its components are [L, a, b] with
L- the lightness with a natural bound between 0 and 1, where 0 represents pure black and 1 represents the lightness of white;a- how green/red the color is; andb- how blue/yellow the color is.
a and b are unbounded, but are usually between -0.5 and 0.5.
This corresponds to the color space in CSS Color Module Level 4  9.2 . It is defined on Björn Ottosson’s blog. It is similar to the CIELAB color space but with improved hue constancy.
Oklab has a cylindrical counterpart: Oklch.