ProphotoRgb

Struct ProphotoRgb 

pub struct ProphotoRgb;
🌌 The ProPhoto RGB color space.

ProPhoto RGB is similar to sRGB but has higher red, green and blue chromaticities, thereby extending its gamut over sRGB on all components. ProPhoto RGB has a reference white of D50; see the XYZ-D65 color space documentation for some background information on the meaning of “reference white.”

Its components are [r, g, b] (red, green, and blue channels respectively), with [0, 0, 0] pure black and [1, 1, 1] white. The natural bounds of the channels are [0, 1].

This corresponds to the color space in CSS Color Module Level 4  10.6 and is characterized by the ICC.

ProPhoto RGB is also known as ROMM RGB.