Struct XyzD50
pub struct XyzD50;Expand description
🌌 The CIE XYZ color space with a 2° observer and a reference white of D50.
Its components are [X, Y, Z]. The components are unbounded, but are usually positive.
Reference white has a luminance Y of 1.
This corresponds to the color space in CSS Color Module Level 4  10.8. It is defined in CIE 015:2018. Following CSS Color Module Level 4  11, the conversion between D50 and D65 white points is done with the standard Bradford linear chromatic adaptation transform.
See the XYZ-D65 color space documentation for some background information on color spaces.