Struct A98Rgb
pub struct A98Rgb;Expand description
🌌 The Adobe RGB (1998) color space.
Adobe RGB is similar to sRGB but has higher green chromaticity, thereby extending its gamut over sRGB on that component. It was developed to encompass typical color print gamuts.
Its components are [r, g, b] (red, green, and blue channels respectively), with [0, 0, 0]
pure black and [1, 1, 1] white. The natural bounds of the channels are [0, 1].
This corresponds to the color space in CSS Color Module Level 4  10.5 and is characterized by the ICC. Adobe RGB is described here by Adobe.