Struct Flags
pub struct Flags {
missing: Missing,
name: u8,
}Expand description
Flags indicating DynamicColor state.
The “missing” flags indicate whether a specific color component is missing (either the three color channels or the alpha channel).
The “named” flag represents whether the dynamic color was parsed from one of the named colors in CSS Color Module Level 4  6.1 or named color space functions in CSS Color Module Level 4  4.1.
The latter is primarily useful for serializing to a CSS-compliant string format.
Fields
missing: Missingname: u8Implementations
impl Flags
impl Flags
pub const fn from_missing(missing: Missing) -> Flags
pub const fn from_missing(missing: Missing) -> Flags
Construct flags with the given missing components.
pub fn set_missing(&mut self, missing: Missing)
pub fn set_missing(&mut self, missing: Missing)
Set the missing components.
pub const fn named(self) -> bool
pub const fn named(self) -> bool
Returns true if the flags indicate the color was generated from a named color or named
color space function.
pub const fn color_name(self) -> Option<&'static str>
pub const fn color_name(self) -> Option<&'static str>
If the color was constructed from a named color, returns that name.
See also parse_color.
pub fn discard_name(&mut self)
pub fn discard_name(&mut self)
Discard the color name or color space name from the flags.