Struct PremulRgba8
#[repr(C)]pub struct PremulRgba8 {
pub r: u8,
pub g: u8,
pub b: u8,
pub a: u8,
}Expand description
A packed representation of pre-multiplied sRGB colors.
Encoding sRGB with 8 bits per component is extremely common, as it is efficient and convenient, even if limited in accuracy and gamut.
This is not meant to be a general purpose color type and is
intended for use with PremulColor::to_rgba8.
For a non-pre-multiplied packed representation, see Rgba8.
Fields
r: u8Red component.
g: u8Green component.
b: u8Blue component.
a: u8Alpha component.
Implementations
impl PremulRgba8
impl PremulRgba8
pub const fn to_u8_array(self) -> [u8; 4]
pub const fn to_u8_array(self) -> [u8; 4]
Returns the color as a [u8; 4].
The color values will be in the order [r, g, b, a].
pub const fn from_u8_array(_: [u8; 4]) -> PremulRgba8
pub const fn from_u8_array(_: [u8; 4]) -> PremulRgba8
Convert the [u8; 4] byte array into a PremulRgba8 color.
The color values must be given in the order [r, g, b, a].
pub const fn to_u32(self) -> u32
pub const fn to_u32(self) -> u32
Returns the color as a little-endian packed value, with r the least significant byte and
a the most significant.
pub const fn from_u32(packed_bytes: u32) -> PremulRgba8
pub const fn from_u32(packed_bytes: u32) -> PremulRgba8
Interpret the little-endian packed value as a color, with r the least significant byte
and a the most significant.