Struct Rec2020
pub struct Rec2020;Expand description
🌌 The Rec. 2020 color space.
Rec. 2020 is similar to sRGB but has higher red, green and blue chromaticities, thereby extending its gamut over sRGB on all components.
Its components are [r, g, b] (red, green, and blue channels respectively), with [0, 0, 0]
pure black and [1, 1, 1] white. The natural bounds of the channels are [0, 1].
This corresponds to the color space in CSS Color Module Level 4  10.7 and is characterized by the ICC. The color space is defined by the International Telecommunication Union here.