Struct Rgba8
#[repr(C)]pub struct Rgba8 {
pub r: u8,
pub g: u8,
pub b: u8,
pub a: u8,
}Expand description
A packed representation of sRGB colors.
Encoding sRGB with 8 bits per component is extremely common, as it is efficient and convenient, even if limited in accuracy and gamut.
This is not meant to be a general purpose color type and is
intended for use with AlphaColor::to_rgba8 and OpaqueColor::to_rgba8.
For a pre-multiplied packed representation, see PremulRgba8.
Fields
r: u8Red component.
g: u8Green component.
b: u8Blue component.
a: u8Alpha component.
Alpha is interpreted as separated alpha.
Implementations
impl Rgba8
impl Rgba8
pub const fn to_u8_array(self) -> [u8; 4]
pub const fn to_u8_array(self) -> [u8; 4]
Returns the color as a [u8; 4].
The color values will be in the order [r, g, b, a].
pub const fn from_u8_array(_: [u8; 4]) -> Rgba8
pub const fn from_u8_array(_: [u8; 4]) -> Rgba8
Convert the [u8; 4] byte array into an Rgba8 color.
The color values must be given in the order [r, g, b, a].